
extern gboolean GdmUseCirclesInEntry;
extern gboolean GdmShowGnomeChooserSession;
extern gboolean GdmShowGnomeFailsafeSession;
extern gboolean GdmShowXtermFailsafeSession;
extern gboolean GdmShowLastSession;
extern gboolean GdmSystemMenu;
extern gboolean GdmConfigAvailable;
extern gchar *GdmHalt;
extern gchar *GdmReboot;
extern gchar *GdmSuspend;
extern gchar *GdmSessionDir;
extern gchar *GdmDefaultLocale;
